aboutsummaryrefslogtreecommitdiff
path: root/src/util.h
diff options
context:
space:
mode:
authorRicardo Velhote <rvelhote@gmail.com>2017-05-14 19:18:26 +0100
committerRicardo Velhote <rvelhote@gmail.com>2017-06-25 20:25:45 +0100
commitc07475294ae2c60f1dcc394922838b1f1f57b476 (patch)
treec319c0083959385a694e7b30ea7f00422c5c82b1 /src/util.h
parentd609fd85ca41c003233d74fbd6c680970ad4a48b (diff)
downloadbitcoin-c07475294ae2c60f1dcc394922838b1f1f57b476.tar.xz
[RPC] Add an uptime command that displays the amount of time that bitcoind has been running
Diffstat (limited to 'src/util.h')
-rw-r--r--src/util.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/src/util.h b/src/util.h
index a4d7aa4db8..824ad51ac4 100644
--- a/src/util.h
+++ b/src/util.h
@@ -5,7 +5,7 @@
/**
* Server/client environment: argument handling, config file parsing,
* logging, thread wrappers
*/
#ifndef BITCOIN_UTIL_H
#define BITCOIN_UTIL_H
@@ -29,6 +29,9 @@
#include <boost/signals2/signal.hpp>
+// Application startup time (used for uptime calculation)
+int64_t GetStartupTime();
+
static const bool DEFAULT_LOGTIMEMICROS = false;
static const bool DEFAULT_LOGIPS = false;
static const bool DEFAULT_LOGTIMESTAMPS = true;
@@ -5,7 +5,7 @@
/**
* Server/client environment: argument handling, config file parsing,
- * logging, thread wrappers
+ * logging, thread wrappers, startup time
*/
#ifndef BITCOIN_UTIL_H